@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2021
+# Copyright (C) 2015-2022
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -38,6 +38,9 @@ from typing import (
     Type,
     cast,
     IO,
+    TypeVar,
+    Generic,
+    overload,
 )
 
 from telegram.utils.types import JSONDict, FileInput
@@ -48,7 +51,7 @@ if TYPE_CHECKING:
 # in PTB-Raw we don't have pytz, so we make a little workaround here
 DTM_UTC = dtm.timezone.utc
 try:
-    import pytz  # pylint: disable=E0401
+    import pytz
 
     UTC = pytz.utc
 except ImportError:
@@ -183,9 +186,7 @@ def _datetime_to_float_timestamp(dt_obj: dtm.datetime) -> float:
 
 
 def _localize(datetime: dtm.datetime, tzinfo: dtm.tzinfo) -> dtm.datetime:
-    """
-    Localize the datetime, where UTC is handled depending on whether pytz is available or not
-    """
+    """Localize the datetime, where UTC is handled depending on whether pytz is available or not"""
     if tzinfo is DTM_UTC:
         return datetime.replace(tzinfo=DTM_UTC)
     return tzinfo.localize(datetime)  # type: ignore[attr-defined]
@@ -247,7 +248,6 @@ def to_float_timestamp(
         ValueError: If ``t`` is a :obj:`datetime.datetime` and :obj:`reference_timestamp` is not
             :obj:`None`.
     """
-
     if reference_timestamp is None:
         reference_timestamp = time.time()
     elif isinstance(time_object, dtm.datetime):
@@ -366,7 +366,6 @@ def effective_message_type(entity: Union['Message', 'Update']) -> Optional[str]:
         :obj:`str`: One of ``Message.MESSAGE_TYPES``
 
     """
-
     # Importing on file-level yields cyclic Import Errors
     from telegram import Message, Update  # pylint: disable=C0415
 
@@ -479,7 +478,6 @@ def decode_user_chat_data_from_json(data: str) -> DefaultDict[int, Dict[object,
     Returns:
         :obj:`dict`: The user/chat_data defaultdict after decoding
     """
-
     tmp: DefaultDict[int, Dict[object, object]] = defaultdict(dict)
     decoded_data = json.loads(data)
     for user, user_data in decoded_data.items():
@@ -494,7 +492,11 @@ def decode_user_chat_data_from_json(data: str) -> DefaultDict[int, Dict[object,
     return tmp
 
 
-class DefaultValue:
+DVType = TypeVar('DVType', bound=object)
+OT = TypeVar('OT', bound=object)
+
+
+class DefaultValue(Generic[DVType]):
     """Wrapper for immutable default arguments that allows to check, if the default value was set
     explicitly. Usage::
 
@@ -531,6 +533,9 @@ class DefaultValue:
         if value:
             ...
 
+    ``repr(DefaultValue(value))`` returns ``repr(value)`` and ``str(DefaultValue(value))`` returns
+    ``f'DefaultValue({value})'``.
+
     Args:
         value (:obj:`obj`): The value of the default argument
 
@@ -539,15 +544,53 @@ class DefaultValue:
 
     """
 
-    def __init__(self, value: object = None):
+    __slots__ = ('value', '__dict__')
+
+    def __init__(self, value: DVType = None):
         self.value = value
 
     def __bool__(self) -> bool:
         return bool(self.value)
 
+    @overload
+    @staticmethod
+    def get_value(obj: 'DefaultValue[OT]') -> OT:
+        ...
+
+    @overload
+    @staticmethod
+    def get_value(obj: OT) -> OT:
+        ...
+
+    @staticmethod
+    def get_value(obj: Union[OT, 'DefaultValue[OT]']) -> OT:
+        """
+        Shortcut for::
+
+            return obj.value if isinstance(obj, DefaultValue) else obj
+
+        Args:
+            obj (:obj:`object`): The object to process
+
+        Returns:
+            Same type as input, or the value of the input: The value
+        """
+        return obj.value if isinstance(obj, DefaultValue) else obj  # type: ignore[return-value]
+
+    # This is mostly here for readability during debugging
+    def __str__(self) -> str:
+        return f'DefaultValue({self.value})'
+
+    # This is here to have the default instances nicely rendered in the docs
+    def __repr__(self) -> str:
+        return repr(self.value)
+
 
 DEFAULT_NONE: DefaultValue = DefaultValue(None)
 """:class:`DefaultValue`: Default :obj:`None`"""
 
 DEFAULT_FALSE: DefaultValue = DefaultValue(False)
 """:class:`DefaultValue`: Default :obj:`False`"""
+
+DEFAULT_20: DefaultValue = DefaultValue(20)
+""":class:`DefaultValue`: Default :obj:`20`"""
